Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(226)

Unified Diff: pkg/analyzer/lib/src/generated/sdk_io.dart

Issue 1212513002: sdk files reorganization to make dart2js a proper package (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: renamed Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analyzer/lib/src/generated/sdk_io.dart
diff --git a/pkg/analyzer/lib/src/generated/sdk_io.dart b/pkg/analyzer/lib/src/generated/sdk_io.dart
index 21dff72cd50cd292515288a5e789ffe8ab00f303..bcdb33d8ed8f92d1c9b16adf1528f09febaa33ac 100644
--- a/pkg/analyzer/lib/src/generated/sdk_io.dart
+++ b/pkg/analyzer/lib/src/generated/sdk_io.dart
@@ -103,11 +103,23 @@ class DirectoryBasedDartSdk implements DartSdk {
/**
* The name of the directory within the SDK directory that contains the
- * libraries file.
+ * sdk_library_metadata directory.
*/
static String _INTERNAL_DIR = "_internal";
/**
+ * The name of the sdk_library_metadata directory that contains the package
+ * holding the libraries.dart file.
+ */
+ static String _SDK_LIBRARY_METADATA_DIR = "sdk_library_metadata";
+
+ /**
+ * The name of the directory within the sdk_library_metadata that contains
+ * libraries.dart.
+ */
+ static String _SDK_LIBRARY_METADATA_LIB_DIR = "lib";
+
+ /**
* The name of the directory within the SDK directory that contains the
* libraries.
*/
@@ -463,7 +475,11 @@ class DirectoryBasedDartSdk implements DartSdk {
*/
LibraryMap initialLibraryMap(bool useDart2jsPaths) {
JavaFile librariesFile = new JavaFile.relative(
- new JavaFile.relative(libraryDirectory, _INTERNAL_DIR),
+ new JavaFile.relative(
+ new JavaFile.relative(
+ new JavaFile.relative(libraryDirectory, _INTERNAL_DIR),
+ _SDK_LIBRARY_METADATA_DIR),
+ _SDK_LIBRARY_METADATA_LIB_DIR),
_LIBRARIES_FILE);
try {
String contents = librariesFile.readAsStringSync();
@@ -515,14 +531,15 @@ class DirectoryBasedDartSdk implements DartSdk {
/**
* An object used to read and parse the libraries file
* (dart-sdk/lib/_internal/libraries.dart) for information about the libraries
* in an SDK. The library information is represented as a Dart file containing a
* single top-level variable whose value is a const map. The keys of the map are
* the names of libraries defined in the SDK and the values in the map are info
* objects defining the library. For example, a subset of a typical SDK might
* have a libraries file that looks like the following:
*
- * final Map<String, LibraryInfo> LIBRARIES = const <LibraryInfo> {
+ * final Map<String, LibraryInfo> LIBRARIES = const <LibraryInfo> {
* // Used by VM applications
* "builtin" : const LibraryInfo(
* "builtin/builtin_runtime.dart",
@@ -515,14 +531,15 @@ class DirectoryBasedDartSdk implements DartSdk {
/**
* An object used to read and parse the libraries file
- * (dart-sdk/lib/_internal/libraries.dart) for information about the libraries
- * in an SDK. The library information is represented as a Dart file containing a
- * single top-level variable whose value is a const map. The keys of the map are
- * the names of libraries defined in the SDK and the values in the map are info
- * objects defining the library. For example, a subset of a typical SDK might
- * have a libraries file that looks like the following:
+ * (dart-sdk/lib/_internal/sdk_library_metadata/lib/libraries.dart) for information
+ * about the libraries in an SDK. The library information is represented as a
+ * Dart file containing a single top-level variable whose value is a const map.
+ * The keys of the map are the names of libraries defined in the SDK and the
+ * values in the map are info objects defining the library. For example, a
+ * subset of a typical SDK might have a libraries file that looks like the
+ * following:
*

Powered by Google App Engine
This is Rietveld 408576698